@@ -152,12 +152,12 @@ impl SourceRef {
             .get("name")
             .and_then(|x| x.as_str())
             .map(|x| x.to_string())
-            .ok_or_else(|| anyhow!("expected name"))?;
+            .ok_or_else(|| anyhow!("expected source.name"))?;
         let url = source
             .get("url")
             .and_then(|x| x.as_str())
             .map(|x| x.to_string())
-            .ok_or_else(|| anyhow!("expected url"))?;
+            .ok_or_else(|| anyhow!("expected source.url"))?;
         let verify_ssl = source
             .get("verify_ssl")
             .and_then(|x| x.as_bool())
@@ -174,7 +174,7 @@ impl SourceRef {
             .get("type")
             .and_then(|x| x.as_str())
             .map_or(Ok(SourceRefType::Index), |x| x.parse::<SourceRefType>())
-            .context("invalid value for type")?;
+            .context("invalid value for source.type")?;
         Ok(SourceRef {
             name,
             url,
@@ -535,6 +535,11 @@ impl Workspace {
         is_rye_managed(&self.doc)
     }
 
+    /// Should requirements.txt based locking include generating hashes?
+    pub fn generate_hashes(&self) -> bool {
+        generate_hashes(&self.doc)
+    }
+
     /// Should requirements.txt based locking include a find-links reference?
     pub fn lock_with_sources(&self) -> bool {
         lock_with_sources(&self.doc)
@@ -1006,7 +1011,15 @@ impl PyProject {
             .unwrap_or(false)
     }
 
-    /// Should requirements.txt based locking include a find-links reference?
+    /// Should requirements.txt-based locking include generating hashes?
+    pub fn generate_hashes(&self) -> bool {
+        match self.workspace {
+            Some(ref workspace) => workspace.generate_hashes(),
+            None => generate_hashes(&self.doc),
+        }
+    }
+
+    /// Should requirements.txt-based locking include a find-links reference?
     pub fn lock_with_sources(&self) -> bool {
         match self.workspace {
             Some(ref workspace) => workspace.lock_with_sources(),
@@ -1252,7 +1265,8 @@ fn get_sources(doc: &DocumentMut) -> Result<Vec<SourceRef>, Error> {
     {
         for source in sources {
             let source = source.context("invalid value for pyproject.toml's tool.rye.sources")?;
-            let source_ref = SourceRef::from_toml_table(source)?;
+            let source_ref = SourceRef::from_toml_table(source)
+                .context("invalid source definition in pyproject.toml")?;
             rv.push(source_ref);
         }
     }
@@ -1280,6 +1294,14 @@ fn is_rye_managed(doc: &DocumentMut) -> bool {
         .unwrap_or(false)
 }
 
+fn generate_hashes(doc: &DocumentMut) -> bool {
+    doc.get("tool")
+        .and_then(|x| x.get("rye"))
+        .and_then(|x| x.get("generate-hashes"))
+        .and_then(|x| x.as_bool())
+        .unwrap_or(false)
+}
+
 fn lock_with_sources(doc: &DocumentMut) -> bool {
     doc.get("tool")
         .and_then(|x| x.get("rye"))
@@ -1299,6 +1321,7 @@ fn get_project_metadata(path: &Path) -> Result<Metadata, Error> {
     }
     serde_json::from_slice(&metadata.stdout).map_err(Into::into)
 }
+
 /// Represents expanded sources.
 #[derive(Debug, Clone, Serialize)]
 pub struct ExpandedSources {
