@@ -105,6 +105,11 @@ pub fn sync(mut cmd: SyncOptions) -> Result<(), Error> {
         bail!("cannot sync or generate lockfile: package needs 'pyproject.toml'");
     }
 
+    // Turn on generate_hashes if the project demands it.
+    if pyproject.generate_hashes() {
+        cmd.lock_options.generate_hashes = true;
+    }
+
     // Turn on locking with sources if the project demands it.
     if pyproject.lock_with_sources() {
         cmd.lock_options.with_sources = true;
@@ -319,6 +324,9 @@ pub fn sync(mut cmd: SyncOptions) -> Result<(), Error> {
 pub fn autosync(
     pyproject: &PyProject,
     output: CommandOutput,
+    pre: bool,
+    with_sources: bool,
+    generate_hashes: bool,
     keyring_provider: KeyringProvider,
 ) -> Result<(), Error> {
     sync(SyncOptions {
@@ -327,7 +335,12 @@ pub fn autosync(
         mode: SyncMode::Regular,
         force: false,
         no_lock: false,
-        lock_options: LockOptions::default(),
+        lock_options: LockOptions {
+            pre,
+            with_sources,
+            generate_hashes,
+            ..Default::default()
+        },
         pyproject: Some(pyproject.toml_path().to_path_buf()),
         keyring_provider,
     })
